.. _package-service:

:mod:`service` Package
======================

.. automodule:: odoo_rpc_client.service
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`db` Module
--------------------

.. automodule:: odoo_rpc_client.service.db
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`object` Module
--------------------

.. automodule:: odoo_rpc_client.service.object
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`report` Module
--------------------

.. automodule:: odoo_rpc_client.service.report
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`service` Module
---------------------

.. automodule:: odoo_rpc_client.service.service
    :members:
    :undoc-members:
    :show-inheritance:

